@@ -13,9 +13,9 @@ rm -rf _checkouts _build
 REBAR_PROFILE=default rebar3 get-deps
 REBAR_PROFILE=test rebar3 get-deps
 mkdir _checkouts
-mv ./_build/default/lib/* _checkouts/
-mv ./_build/default/plugins/* _checkouts/
-mv ./_build/test/lib/meck _checkouts/
+mv -n ./_build/default/lib/* _checkouts/
+mv -n ./_build/default/plugins/* _checkouts/
+mv -n ./_build/test/lib/meck _checkouts/
 # delete erlang bytecode
 find _checkouts/ -iname '*beam' -delete
 tar czf build_dep.tar.gz ./_checkouts
